"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addValidateCLI = void 0;
const commander_1 = require("commander");
const myst_cli_utils_1 = require("myst-cli-utils");
const session_1 = require("../session");
const validate_1 = require("../validate");
function makeValidateCLI(program) {
    const command = new commander_1.Command('validate')
        .description(`
      Validate JATS file against DTD schema.
      
      The JATS DTD schema file is fetched from nih.gov ftp server if not available locally.
      This will attempt to infer the specific JATS DTD version, library, etc from the file header,
      but options are available to override the inferred values.
      `)
        .argument('<file>', 'JATS file to validate')
        .addOption(new commander_1.Option('--library <value>', 'JATS library - archiving, publishing, or authoring (default: archiving, if value cannot be inferred from file)'))
        .addOption(new commander_1.Option('--jats <version>', 'JATS version, must be 1.1 or later (default: 1.3, if value cannot be inferred from file)'))
        .addOption(new commander_1.Option('--mathml <version>', 'MathML version, 2 or 3 (default: 3, if value cannot be inferred from file)'))
        .addOption(new commander_1.Option('--oasis', 'Use OASIS table model (default: false, if value cannot be inferred from file)'))
        .addOption(new commander_1.Option('--directory <value>', 'Directory to save DTD file'))
        .action((0, myst_cli_utils_1.clirun)(validate_1.validateJatsAgainstDtdWrapper, { program, getSession: session_1.getSession }));
    return command;
}
function addValidateCLI(program) {
    program.addCommand(makeValidateCLI(program));
}
exports.addValidateCLI = addValidateCLI;
